pub struct BasicAuthCredential { /* private fields */ }Expand description
A username/password pair accepted by HTTP Basic authentication.
Implementations
Sourceimpl BasicAuthCredential
impl BasicAuthCredential
Sourcepub fn new(username: impl AsRef<str>, password: impl AsRef<str>) -> Self
pub fn new(username: impl AsRef<str>, password: impl AsRef<str>) -> Self
Creates a credential from the exact username and password bytes.
HTTP Basic authentication uses the first colon as the username/password
separator, so usernames should not contain :. Passwords may contain
colons. Serve authenticated endpoints only through HTTPS or trusted TLS
termination because HTTP Basic credentials are not encrypted.