pub struct WebhookFilterError { /* private fields */ }Expand description
An invalid organizer or event filter value.
The rejected value is never included in the message so that diagnostics can be reported without disclosing configured policy.